==> plf-community-sources-1.4.0.zip: platform-sources-1.4.0/commons-6.4.0/commons-component-common/src/test/java/org/exoplatform/jpa/settings/impl/JPAUserSettingServiceTest.java <==
package org.exoplatform.jpa.settings.impl;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Set;

import org.exoplatform.commons.api.notification.NotificationContext;
import org.exoplatform.commons.api.notification.channel.AbstractChannel;
import org.exoplatform.commons.api.notification.channel.ChannelManager;
import org.exoplatform.commons.api.notification.channel.template.AbstractTemplateBuilder;
import org.exoplatform.commons.api.notification.channel.template.TemplateProvider;
import org.exoplatform.commons.api.notification.model.ChannelKey;
import org.exoplatform.commons.api.notification.model.PluginKey;
import org.exoplatform.commons.api.notification.model.UserSetting;
import org.exoplatform.commons.api.notification.plugin.config.PluginConfig;
import org.exoplatform.commons.notification.channel.MailChannel;
import org.exoplatform.commons.utils.CommonsUtils;
import org.exoplatform.jpa.BaseTest;
import org.exoplatform.services.organization.OrganizationService;
import org.exoplatform.services.organization.User;
import org.exoplatform.services.organization.idm.UserImpl;
import org.exoplatform.settings.jpa.JPAPluginSettingServiceImpl;
import org.exoplatform.settings.jpa.JPAUserSettingServiceImpl;

public class JPAUserSettingServiceTest extends BaseTest {

  private static final String       GROUP_PROVIDER_ID = "groupId";

  private static final String       PLUGIN_ID         = "pluginAllowedId";

  private static final String       CHANNEL_ID        = "channelId";

  private static final PluginConfig PLUGIN_CONFIG     = new PluginConfig();
  static {
    PLUGIN_CONFIG.setPluginId(PLUGIN_ID);
    PLUGIN_CONFIG.setGroupId(GROUP_PROVIDER_ID);
    PLUGIN_CONFIG.setDefaultConfig(Collections.singletonList(UserSetting.FREQUENCY.INSTANTLY.name()));
    PLUGIN_CONFIG.addAdditionalChannel(CHANNEL_ID);
  }

  JPAUserSettingServiceImpl   userSettingService;

  JPAPluginSettingServiceImpl pluginSettingServiceImpl;

  ChannelManager              channelManager;

  OrganizationService         organizationService;

  List<String>                dispatchedUsers;

  List<String>                dispatchedPlugins;

  AbstractChannel             specificChannel = new AbstractChannel() {
                                                @Override
                                                public void registerTemplateProvider(TemplateProvider provider) {
                                                  // No
                                                  // Template
                                                  // Provider
                                                }

                                                @Override
                                                protected AbstractTemplateBuilder getTemplateBuilderInChannel(PluginKey key) {
                                                  // No
                                                  // template
                                                  // builder
                                                  return null;
                                                }

                                                @Override
                                                public ChannelKey getKey() {
                                                  return ChannelKey.key(CHANNEL_ID);
                                                }

                                                @Override
                                                public String getId() {
                                                  return CHANNEL_ID;
                                                }

                                                @Override
                                                public void dispatch(NotificationContext ctx, String userId) {
                                                  dispatchedUsers.add(userId);
                                                  dispatchedPlugins.add(ctx.getNotificationInfo().getKey().getId());
                                                }

                                                public boolean isDefaultChannel() {
                                                  return false;
                                                };
                                              };

  @Override
  public void setUp() {
    super.setUp();
    userSettingService = getService(JPAUserSettingServiceImpl.class);
    pluginSettingServiceImpl = getService(JPAPluginSettingServiceImpl.class);
    channelManager = getService(ChannelManager.class);
    organizationService = getService(OrganizationService.class);

    pluginSettingServiceImpl.registerPluginConfig(PLUGIN_CONFIG);
    channelManager.register(specificChannel);
    dispatchedUsers = new ArrayList<>();
    dispatchedPlugins = new ArrayList<>();
  }

  @Override
  protected void tearDown() {
    for (int i = 0; i < 10; i++) {
      try {
        organizationService.getUserHandler().removeUser("userTest_" + i, false);
      } catch (Exception e) {
        e.printStackTrace();
      }
    }
    channelManager.unregister(specificChannel);
    pluginSettingServiceImpl.unregisterPluginConfig(PLUGIN_CONFIG);
    super.tearDown();
  }

  public void test_1_GetDefautSetting() throws Exception {
    List<UserSetting> list = userSettingService.getDigestDefaultSettingForAllUser(0, 0);
    int originalSize = list.size();

    for (int i = 0; i < 10; i++) {
      User user = new UserImpl("userTest_" + i);
      organizationService.getUserHandler().createUser(user, false);
      userSettingService.initDefaultSettings(user.getUserName());
    }
    list = userSettingService.getDigestDefaultSettingForAllUser(0, 5);
    assertEquals(5, list.size());

    list = userSettingService.getDigestDefaultSettingForAllUser(0, 0);
    assertEquals(10 + originalSize, list.size());
  }

  public void testNotAllowedChannel() throws Exception {
    String username = "userAllowedTest";
    User user = new UserImpl(username);
    organizationService.getUserHandler().createUser(user, false);
    userSettingService.initDefaultSettings(username);

    UserSetting userSetting = userSettingService.get(username);
    assertNotNull(userSetting);

    Set<String> channelActives = userSetting.getChannelActives();
    assertTrue(channelActives.contains(CHANNEL_ID));
    for (String channelId : channelActives) {
      assertTrue(userSetting.isActive(channelId, PLUGIN_ID));
      assertTrue(pluginSettingServiceImpl.isActive(channelId, PLUGIN_ID));
    }

    List<String> allowedPlugins = userSetting.getAllChannelPlugins().get(CHANNEL_ID);
    assertEquals(Collections.singletonList(PLUGIN_ID), allowedPlugins);

    assertTrue(pluginSettingServiceImpl.isActive(CHANNEL_ID, PLUGIN_ID));
    assertTrue(pluginSettingServiceImpl.isAllowed(CHANNEL_ID, PLUGIN_ID));

    for (String channelId : channelActives) {
      pluginSettingServiceImpl.saveActivePlugin(channelId, PLUGIN_ID, false);
      assertFalse(pluginSettingServiceImpl.isActive(channelId, PLUGIN_ID));
      userSetting = userSettingService.get(username);
      assertFalse(userSetting.isActive(channelId, PLUGIN_ID));
    }

    for (String channelId : channelActives) {
      pluginSettingServiceImpl.saveActivePlugin(channelId, PLUGIN_ID, true);
      assertTrue(pluginSettingServiceImpl.isActive(channelId, PLUGIN_ID));
      userSetting = userSettingService.get(username);
      assertTrue(userSetting.isActive(channelId, PLUGIN_ID));
    }

  }

  public void testDisabledUser() throws Exception {
    User u = CommonsUtils.getService(OrganizationService.class).getUserHandler().createUserInstance("binh");
    u.setEmail("email@test");
    u.setFirstName("first");
    u.setLastName("last");
    u.setPassword("pwdADDSomeSaltToBeCompliantWithSomeIS00");
    CommonsUtils.getService(OrganizationService.class).getUserHandler().createUser(u, true);

    String pluginId = "TestPlugin";
    userSettingService.save(createUserSetting("binh", Arrays.asList(pluginId), null, null));
    UserSetting userSetting = userSettingService.get("binh");
    assertTrue(userSetting.isEnabled());
    assertTrue(userSetting.isChannelActive(MailChannel.ID, pluginId));

    // disable user "binh"
    CommonsUtils.getService(OrganizationService.class).getUserHandler().setEnabled("binh", false, true);
    userSetting = userSettingService.get("binh");
    assertFalse(userSetting.isEnabled());
    assertFalse(userSetting.isChannelActive(MailChannel.ID, pluginId));

    // enable user "root" but not change the active channel status
    CommonsUtils.getService(OrganizationService.class).getUserHandler().setEnabled("binh", true, true);
    userSetting = userSettingService.get("binh");
    assertTrue(userSetting.isEnabled());
    assertTrue(userSetting.isChannelActive(MailChannel.ID, pluginId));

    CommonsUtils.getService(OrganizationService.class).getUserHandler().removeUser("binh", false);
    assertNull(CommonsUtils.getService(OrganizationService.class).getUserHandler().findUserByName("binh"));

  }

  private UserSetting createUserSetting(String userId, List<String> instantly, List<String> daily, List<String> weekly) {
    UserSetting model = new UserSetting();
    model.setUserId(userId);
    model.setChannelActive(MailChannel.ID);
    model.setDailyPlugins(daily);
    model.setChannelPlugins(MailChannel.ID, instantly);
    model.setWeeklyPlugins(weekly);
    return model;
  }
}

==> plf-community-sources-5.3.2.zip: platform-sources-5.3.2/commons-5.3.2/commons-component-common/src/test/java/org/exoplatform/jpa/settings/impl/JPAUserSettingServiceTest.java <==
package org.exoplatform.jpa.settings.impl;

import java.util.List;

import org.exoplatform.commons.api.notification.model.UserSetting;
import org.exoplatform.commons.notification.channel.MailChannel;
import org.exoplatform.commons.utils.CommonsUtils;
import org.exoplatform.component.test.ConfigurationUnit;
import org.exoplatform.component.test.ConfiguredBy;
import org.exoplatform.component.test.ContainerScope;
import org.exoplatform.jpa.BaseTest;
import org.exoplatform.services.organization.OrganizationService;
import org.exoplatform.services.organization.User;
import org.exoplatform.services.organization.idm.UserImpl;
import org.exoplatform.settings.jpa.JPAUserSettingServiceImpl;

@ConfiguredBy({
    @ConfigurationUnit(scope = ContainerScope.PORTAL, path = "conf/standalone/test-jpa-configuration.xml"),
    @ConfigurationUnit(scope = ContainerScope.PORTAL, path = "conf/standalone/test-notification-configuration.xml")
})
public class JPAUserSettingServiceTest extends BaseTest {

  protected static JPAUserSettingServiceImpl userSettingService;
  protected static OrganizationService organizationService;

  @Override
  public void setUp() {
    super.setUp();
    userSettingService = getService(JPAUserSettingServiceImpl.class);
    organizationService = getService(OrganizationService.class);
  }

  @Override
  protected void tearDown() {
    for (int i = 0; i < 10; i++) {
      try {
        organizationService.getUserHandler().removeUser("user_" + i, false);
      } catch (Exception e) {
        e.printStackTrace();
      }
    }
  }

  public void test_1_GetDefautSetting() throws Exception {
    for (int i = 0; i < 10; i++) {
      User user = new UserImpl("user_" + i);
      organizationService.getUserHandler().createUser(user, false);
      userSettingService.initDefaultSettings(user.getUserName());
    }
    List<UserSetting> list = userSettingService.getDigestDefaultSettingForAllUser(0, 5);

    assertEquals(5, list.size());

    list = userSettingService.getDigestDefaultSettingForAllUser(0, 0);

    assertEquals(10, list.size());
  }

  public void testDisabledUser() throws Exception {
    User u = CommonsUtils.getService(OrganizationService.class).getUserHandler().createUserInstance("binh");
    u.setEmail("email@test");
    u.setFirstName("first");
    u.setLastName("last");
    u.setPassword("pwdADDSomeSaltToBeCompliantWithSomeIS00");
    CommonsUtils.getService(OrganizationService.class).getUserHandler().createUser(u, true);

    userSettingService.save(createUserSetting("binh", null, null, null));
    UserSetting userSetting = userSettingService.get("binh");
    assertTrue(userSetting.isEnabled());
    assertTrue(userSetting.isChannelActive(MailChannel.ID));

    //disable user "root"
    CommonsUtils.getService(OrganizationService.class).getUserHandler().setEnabled("binh", false, true);
    userSetting = userSettingService.get("binh");
    assertTrue(userSetting.isChannelActive(MailChannel.ID));
    assertFalse(userSetting.isEnabled());

    //enable user "root" but not change the active channel status
    CommonsUtils.getService(OrganizationService.class).getUserHandler().setEnabled("binh", true, true);
    userSetting = userSettingService.get("binh");
    assertTrue(userSetting.isChannelActive(MailChannel.ID));
    assertTrue(userSetting.isEnabled());

    CommonsUtils.getService(OrganizationService.class).getUserHandler().removeUser("binh", false);
    assertNull(CommonsUtils.getService(OrganizationService.class).getUserHandler().findUserByName("binh"));

  }

  private UserSetting createUserSetting(String userId, List<String> instantly, List<String> daily, List<String> weekly) {
    UserSetting model = new UserSetting();
    model.setUserId(userId);
    model.setChannelActive(UserSetting.EMAIL_CHANNEL);
    model.setDailyPlugins(daily);
    model.setChannelPlugins(UserSetting.EMAIL_CHANNEL, instantly);
    model.setWeeklyPlugins(weekly);
    return model;
  }
}
